==> huaweicloudsdkdas-3.0.61-py2.py3-none-any.whl: huaweicloudsdkdas/v3/model/list_metadata_locks_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListMetadataLocksResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'metadata_locks': 'list[MetadataLock]',
        'count': 'int'
    }

    attribute_map = {
        'metadata_locks': 'metadata_locks',
        'count': 'count'
    }

    def __init__(self, metadata_locks=None, count=None):
        """ListMetadataLocksResponse - a model defined in huaweicloud sdk"""
        
        super(ListMetadataLocksResponse, self).__init__()

        self._metadata_locks = None
        self._count = None
        self.discriminator = None

        if metadata_locks is not None:
            self.metadata_locks = metadata_locks
        if count is not None:
            self.count = count

    @property
    def metadata_locks(self):
        """Gets the metadata_locks of this ListMetadataLocksResponse.

        元数据锁列表

        :return: The metadata_locks of this ListMetadataLocksResponse.
        :rtype: list[MetadataLock]
        """
        return self._metadata_locks

    @metadata_locks.setter
    def metadata_locks(self, metadata_locks):
        """Sets the metadata_locks of this ListMetadataLocksResponse.

        元数据锁列表

        :param metadata_locks: The metadata_locks of this ListMetadataLocksResponse.
        :type: list[MetadataLock]
        """
        self._metadata_locks = metadata_locks

    @property
    def count(self):
        """Gets the count of this ListMetadataLocksResponse.

        元数据锁数量

        :return: The count of this ListMetadataLocksResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListMetadataLocksResponse.

        元数据锁数量

        :param count: The count of this ListMetadataLocksResponse.
        :type: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListMetadataLocksResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdas-3.0.99-py2.py3-none-any.whl: huaweicloudsdkdas/v3/model/list_metadata_locks_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListMetadataLocksResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'metadata_locks': 'list[MetadataLock]',
        'count': 'int'
    }

    attribute_map = {
        'metadata_locks': 'metadata_locks',
        'count': 'count'
    }

    def __init__(self, metadata_locks=None, count=None):
        """ListMetadataLocksResponse

        The model defined in huaweicloud sdk

        :param metadata_locks: 元数据锁列表
        :type metadata_locks: list[:class:`huaweicloudsdkdas.v3.MetadataLock`]
        :param count: 元数据锁数量
        :type count: int
        """
        
        super(ListMetadataLocksResponse, self).__init__()

        self._metadata_locks = None
        self._count = None
        self.discriminator = None

        if metadata_locks is not None:
            self.metadata_locks = metadata_locks
        if count is not None:
            self.count = count

    @property
    def metadata_locks(self):
        """Gets the metadata_locks of this ListMetadataLocksResponse.

        元数据锁列表

        :return: The metadata_locks of this ListMetadataLocksResponse.
        :rtype: list[:class:`huaweicloudsdkdas.v3.MetadataLock`]
        """
        return self._metadata_locks

    @metadata_locks.setter
    def metadata_locks(self, metadata_locks):
        """Sets the metadata_locks of this ListMetadataLocksResponse.

        元数据锁列表

        :param metadata_locks: The metadata_locks of this ListMetadataLocksResponse.
        :type metadata_locks: list[:class:`huaweicloudsdkdas.v3.MetadataLock`]
        """
        self._metadata_locks = metadata_locks

    @property
    def count(self):
        """Gets the count of this ListMetadataLocksResponse.

        元数据锁数量

        :return: The count of this ListMetadataLocksResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListMetadataLocksResponse.

        元数据锁数量

        :param count: The count of this ListMetadataLocksResponse.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListMetadataLocksResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
